import { ref, computed } from "vue";
import { defineStore } from "pinia";

export interface item {
  id: string;
  img: string;
  title: string;
}

export interface settings {
  colcount: number;
}

export const useDataStorage = defineStore("data", {
  state: () => {
    return {
      items: [] as Array<item>,
      colcount: 0 as number,
    };
  },
  getters: {
    item: (state) => (item: string) => state.items.find((elem) => elem.id == item) ?? ({} as item),
  },
  actions: {
    load() {
      let store = localStorage.getItem("staende");
      let setting = localStorage.getItem("settings");
      if (store) this.items = JSON.parse(store);
      if (setting) this.colcount = JSON.parse(setting).colcount ?? 0;
    },
    create(title: string, img: string) {
      this.items.push({
        id: Date.now().toString(16),
        title: title,
        img: img,
      });
      let string = JSON.stringify(this.items);
      localStorage.setItem("staende", string);
    },
    update(id: string, title: string, img: string) {
      let item = this.items.find((elem) => elem.id == id);
      if (item) {
        item.img = img;
        item.title = title;
        let string = JSON.stringify(this.items);
        localStorage.setItem("staende", string);
      }
    },
    delete(id: string) {
      let index = this.items.findIndex((elem) => elem.id == id);
      if (index != -1) this.items.splice(index, 1);
      let string = JSON.stringify(this.items);
      localStorage.setItem("staende", string);
    },
    saveSettings(data: settings) {
      this.colcount = data.colcount;
      localStorage.setItem("settings", JSON.stringify(data));
    },
    importData(event: Event) {
      var file = (event.target as HTMLInputElement).files?.[0];
      if (!file) return;
      const reader = new FileReader();

      reader.onload = () => {
        if (typeof reader.result == "string" && reader.result.startsWith("FORMAT-UG-ÖEL:")) {
          var result = reader.result.replace("FORMAT-UG-ÖEL:", "");
          this.items = JSON.parse(result);
          localStorage.setItem("staende", result);
        } else {
          alert("Datei entspricht nicht dem Import Format");
        }
      };

      if (file) {
        reader.readAsText(file);
      }
    },
    exportData() {
      var data = "FORMAT-UG-ÖEL:" + localStorage.getItem("staende");
      var downloadableLink = document.createElement("a");
      downloadableLink.setAttribute("href", "data:text/plain;charset=utf-8," + encodeURIComponent(data ?? ""));
      downloadableLink.download = "UG_OeEL_Pegel_Messstelle.txt";
      downloadableLink.click();
    },
  },
});
